Kally Project
===============
This is an alternative algorithm test project for clustering besides kmean and others. This project is funded by the Muhammadiyah University of Ponorogo, Indonesia. This algorithm is based on the philosophy of competence looking for allies.
Complete research results on this algorithm can be seen at https://github.com/elangbijak4/k-ally.1.0

Installing
============

.. code-block:: bash

    pip install kally

Usage
=====

.. code-block:: bash

    >>> import kally
    >>> result=kally(data,columns,k=3,min_index_data=0,iteration=10,treshold=0.05)